@@ -2,9 +2,6 @@ package Moodle::Library;
 
 use Data::Object 'Library';
 
-our $Migrator = declare "Migrator",
-  as InstanceOf["Doodle::Migrator"];
-
 our $MysqlDriver = declare "MysqlDriver",
   as InstanceOf["Mojo::mysql"];
 
@@ -17,6 +14,9 @@ our $SqliteDriver = declare "SqliteDriver",
 our $Driver = declare "Driver",
   as $MysqlDriver | $PostgresDriver | $SqliteDriver;
 
+our $Migrator = declare "Migrator",
+  as InstanceOf["Doodle::Migration"];
+
 1;
 
 =encoding utf8
